<?php
require_once __DIR__ . '/vendor/autoload.php';
session_start();
use \Slim\Slim as Slim;
use Illuminate\Database\Capsule\Manager as DB;
use \gp\controleurs\ControleurPrincipal as ControleurPrincipal;
use \gp\controleurs\ControleurGame as ControleurGame;
use \gp\controleurs\ControleurPlatform as ControleurPlatform;
use \gp\controleurs\ControleurCharacter as ControleurCharacter;

$db = new DB();
$db->addConnection(parse_ini_file('./conf/conf.ini'));

$db->setAsGlobal();
$db->bootEloquent();

$app = new \Slim\Slim();

$app->get('/',function () use ($app) {
    $c = new ControleurPrincipal();
    $c->afficherAccueil();
    $app->response->headers->set('Content-Type', 'text/html');
});

/* ------------------------------------------------------------
 * GAMES
 * ------------------------------------------------------------
 */

// Affiche un jeu au fromat JSON
$app->get('/api/games/:id',function ($id) use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurGame();
    $c->getGame($id);
})->name('getGame');
// Affiche tous les jeu paginé au format JSON
$app->get('/api/games/',function () use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurGame();
    $c->getGames();
})->name('getGames');
// Affiche les commentaires d'un jeu
$app->get('/api/games/:id/comments',function ($id) use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurGame();
    $c->getGameComments($id);
});
$app->get('/api/games/:id/characters',function ($id) use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurGame();
    $c->getGameCharacters($id);
});
$app->get('/api/games/:id/platforms',function ($id) use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurGame();
    $c->getGamePlatforms($id);
});

/* ------------------------------------------------------------
 * PLATFORMS
 * ------------------------------------------------------------
 */
$app->get('/api/platforms/:id',function ($id) use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurPlatform();
    $c->getPlatform($id);
})->name('getPlatform');
$app->get('/api/platforms/',function () use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurPlatform();
    $c->getPlatforms();
})->name('getPlatforms');
/* ------------------------------------------------------------
 * CHARACTERS
 * ------------------------------------------------------------
 */
$app->get('/api/characters/:id',function ($id) use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurCharacter();
    $c->getCharacter($id);
})->name('getCharacter');
$app->get('/api/characters/',function () use ($app){
    $app->response->headers->set('Content-Type', 'application/json');
    $c = new ControleurCharacter();
    $c->getCharacters();
})->name('getCharacters');

$app->run();